package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.34.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,``P`!````H!8``#0````8T0```````#0`(``)
M`"@`&@`9``8````T````-````#0````@`0``(`$```0````$`````P```%0!
M``!4`0``5`$```L````+````!`````$````!````````````````````V+$`
M`-BQ```%`````!````$`````P````,````#````0$```4!0```8`````$```
M`@````C````(P```",```!`!```0`0``!@````0````$````8`$``&`!``!@
M`0``1````$0````$````!````%#E=&1`HP``0*,``$"C```,`0``#`$```0`
M```$````4>5T9```````````````````````````!@```!````!2Y71D`,``
M``#`````P````!`````0```$`````0```"]L:6(O;&0N<V\```0````4````
M`P```$=.50"3M&2\!U]U[B<^+DN1LX2T=N@GL00````0`````0```$=.50`!
M````````````````````$0```$0````(````"``````0$`0E0`2`*`$`!:"&
M`(2``0``"R@$"#B@$D6*```(`````$0```!'````2@```$L```!2````4P``
M`%0```!6````5P```%D```!:````7````%T```!>``````````````!NQ=\?
MSMY'+6M_FGPNQ9NVU&34?"'_Y`[9<5@<XD?&`;(!BV^L2^/`0OK7A\+E/RRZ
MXY)\^Z%L8&L)0]9GK\QF0D75[(D'<-,-%.*>,F+;[=O-XYX5C"7,##J7"UGH
M[>Q_J9R;:QJ>4*/@^TD`````````````````````)0(`````````````$@``
M`+8!`````````````!(```"]```````````````2````B@(`````````````
M$0```&8#`````````````!(```!-```````````````2````FP``````````
M````$0````@"`````````````!(````V`0`````````````2````Q`$`````
M````````$@```#L"`````````````!(```!J`@`````````````2````P@``
M````````````$@```(L"`````````````"$```#K`0`````````````2````
M'@(`````````````$0```-,``````````````!(````!```````````````@
M````IP$`````````````$@```!8"`````````````!(````$`0``````````
M```2````]```````````````$@```$H"`````````````!(```#2`0``````
M```````2````Y@``````````````$@```-\!`````````````!(```!Q`@``
M```````````2````5`$`````````````$@```'@"`````````````!(```"O
M`0`````````````2`````0(`````````````$@```!```````````````!(`
M```F`0`````````````2````+0``````````````$@```(H`````````````
M`!(````^```````````````2````B0$`````````````$@```.8!````````
M`````!(```!-`0`````````````2````V0$`````````````$@```)0"````
M`````````!(```!N```````````````2````D0$`````````````$@```,L!
M`````````````!(```!?`0`````````````2````&`$`````````````$@``
M`*8``````````````!(```#'```````````````2````I@(`````````````
M$@```$,"`````````````!(```"A`0`````````````2``````(`````````
M````$@```"P"`````````````!(```!9```````````````2````^0$`````
M````````$@```$$!`````````````!(````U`@`````````````2````C`(`
M````````````$0```%0"`````````````!(```!]```````````````1````
M8@(`````````````$@```',!`````````````!(```"$`0`````````````2
M````O0$`````````````$@```)H!`````````````!(````-`0``````````
M```2````'@``````````````$@```&\#``#P,0``"@$``!(`#0#4`P``X"<`
M`)8'```2``T`A0(``%`4``!(`@``$@`-`.4"``"`'@```P```!(`#0`:`P``
M@"\``&8"```2``T`^@,``)`>```%`@``$@`-`+H#```0T````````!``%P#V
M`@``H"```",````2``T`,`,``#`F``!V````$@`-`'L#```<9```!````!$`
M#P"7`P``4%\```D"```2``T`H@,``$`>```[````$@`-`,\#``!0U```````
M`!``%P#H`P``X"8``/4````2``T`B@,```#0````````$``6`#X#``#0(```
M]0```!(`#0#A`P``$-`````````0`!8`!P0```S0```$````$0`6``,#``"P
M8P```0```!(`#0"0`P``H!8``#<````2``T`J@,``%!C``!=````$@`-`,8#
M``#`7@``@P```!(`#0",`P```-`````````@`!8`$P,``!AD```$````$0`/
M`%0#``"P)@``*P```!(`#0!*`P``8&$``.`!```2``T`$00``-`A``!8!```
M$@`-``!?7V=M;VY?<W1A<G1?7P!097)L7W-Y<U]T97)M`%!E<FQ?<WES7VEN
M:70S`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]G971?
M<W8`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]S=E]S971P=FX`4$Q?9&]?
M=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!097)L7V-R;V%K
M7VUE;6]R>5]W<F%P`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R
M:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R
M=6X`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`&)O;W1?1'EN84QO861E<@!P
M97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`'!T:')E
M861?9V5T<W!E8VEF:6,`7U]E<G)N;U]L;V-A=&EO;@!E>&ET`'-T<FYC;7``
M8VQO<V5D:7(`=6YL:6YK`&UK9&ER`')E86QL;V,`;65M8VAR`&=E='!I9`!S
M=')D=7``<W1R=&]K`'-T<FQE;@!S=')S='(`<FUD:7(`;W!E;C8T`')E860`
M7U]F<')I;G1F7V-H:P!M96UC<'D`;'-T870V-`!?7W-T<FYC<'E?8VAK`&]P
M96YD:7(`<W1D97)R`&=E='5I9`!R96%D;&EN:P!C;&]S90!L<V5E:S8T`'-T
M<F-H<@!R96%D9&ER-C0`7U]S<')I;G1F7V-H:P!M96UM;W9E`&%C8V5S<P!S
M=')C;7``7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N`%]?<F5G:7-T97)?
M871F;W)K`%]?<W1A8VM?8VAK7V9A:6P`;&EB<&5R;"YS;RXU+C,T`&QI8G!T
M:')E860N<V\N,"XS`&QI8F,N<V\N,"XS`'!A<E]C=7)R96YT7V5X96,`<&%R
M7V)A<V5N86UE`%]?;&EB8U]C<W5?9FEN:0!?9G!?:'<`6%-?26YT97)N86QS
M7U!!4E]"3T]4`'!A<E]E;G9?8VQE86X`<&%R7V1I<FYA;64`<VAA7V9I;F%L
M`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%])3U]S
M=&1I;E]U<V5D`%]?9&%T85]S=&%R=`!S:&%?=7!D871E`'AS7VEN:70`7U]L
M:6)C7V-S=5]I;FET`%]?8G-S7W-T87)T`'-H85]I;FET`%]E;F0`<&%R7VUK
M=&UP9&ER`%]E9&%T80!P87)?<V5T=7!?;&EB<&%T:`!P87)?9FEN9'!R;V<`
M;7E?<&%R7W!L`'!A<E]I;FET7V5N=@!'3$E"0U\R+C(N-@!'3$E"0U\R+C$R
M`$=,24)#7S(N-`!'3$E"0U\R+C(R`$=,24)#7S(N,S,`1TQ)0D-?,BXS+C0`
M`````@`"``$``@`"``$``0`#``$``@`"``(``@`"``,``@`!``$``@`"``$`
M`0`"``(``0`"``(``0`"``(`!``!``$``0`!``$``@`"``(``@`%``$``@`"
M``8``0`!``$`!P`"``(`!``"``$``@`!``(``@`#``$``@`(``(``@`"``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``(`QP(``!`````P````=AII"0``"``>!```$````)*1
ME@8```8`*@0````````!``4`V0(``!``````````%&EI#0``!P`U!```$```
M`(*1E@8```4`/P0``!````"SD98&```$`$H$```0````=!EI"0```P!5!```
M$````'8::0D```(`'@0```````#Q%@``"````/86```(````#!<```@````Q
M%P``"````#87```(````61<```@```!R%P``"````(87```(`````,````@`
M```$P```"`````S0```(````",(```8'```,P@``!A```!#"```&$0``%,(`
M``82```8P@``!B$``!S"```&(@``(,(```8Z```DP@``!CP``"3!```'`0``
M*,$```<"```LP0``!P,``##!```'!0``-,$```<&```XP0``!P@``#S!```'
M"0``0,$```<*``!$P0``!PL``$C!```'#```3,$```<-``!0P0``!P\``%3!
M```'$P``6,$```<4``!<P0``!Q4``&#!```'%@``9,$```<7``!HP0``!Q@`
M`&S!```'&0``<,$```<:``!TP0``!QL``'C!```''```?,$```<=``"`P0``
M!QX``(3!```''P``B,$```<@``",P0``!R,``)#!```')```E,$```<E``"8
MP0``!R8``)S!```')P``H,$```<H``"DP0``!RD``*C!```'*@``K,$```<K
M``"PP0``!RP``+3!```'+0``N,$```<N``"\P0``!R\``,#!```',```Q,$`
M``<Q``#(P0``!S(``,S!```',P``T,$```<T``#4P0``!S4``-C!```'-@``
MW,$```<W``#@P0``!S@``.3!```'.0``Z,$```<[``#LP0``!ST``/#!```'
M/@``],$```<_``#XP0``!T```/S!```'00```,(```="```$P@``!T,``%.#
M[`CH4P8``('#B[```(N#_````(7`=`+_T(/$"%O#````````````````_[,$
M````_Z,(`````````/^C#````&@`````Z>#_____HQ````!H"````.G0____
M_Z,4````:!````#IP/____^C&````&@8````Z;#_____HQP```!H(````.F@
M_____Z,@````:"@```#ID/____^C)````&@P````Z8#_____HR@```!H.```
M`.EP_____Z,L````:$````#I8/____^C,````&A(````Z5#_____HS0```!H
M4````.E`_____Z,X````:%@```#I,/____^C/````&A@````Z2#_____HT``
M``!H:````.D0_____Z-$````:'````#I`/____^C2````&AX````Z?#^____
MHTP```!H@````.G@_O___Z-0````:(@```#IT/[___^C5````&B0````Z<#^
M____HU@```!HF````.FP_O___Z-<````:*````#IH/[___^C8````&BH````
MZ9#^____HV0```!HL````.F`_O___Z-H````:+@```#I</[___^C;````&C`
M````Z6#^____HW````!HR````.E0_O___Z-T````:-````#I0/[___^C>```
M`&C8````Z3#^____HWP```!HX````.D@_O___Z.`````:.@```#I$/[___^C
MA````&CP````Z0#^____HX@```!H^````.GP_?___Z.,````:``!``#IX/W_
M__^CD````&@(`0``Z=#]____HY0```!H$`$``.G`_?___Z.8````:!@!``#I
ML/W___^CG````&@@`0``Z:#]____HZ````!H*`$``.F0_?___Z.D````:#`!
M``#I@/W___^CJ````&@X`0``Z7#]____HZP```!H0`$``.E@_?___Z.P````
M:$@!``#I4/W___^CM````&A0`0``Z4#]____H[@```!H6`$``.DP_?___Z.\
M````:&`!``#I(/W___^CP````&AH`0``Z1#]____H\0```!H<`$``.D`_?__
M_Z/(````:'@!``#I\/S___^CS````&B``0``Z>#\____H]````!HB`$``.G0
M_/___Z/4````:)`!``#IP/S___^CV````&B8`0``Z;#\____H]P```!HH`$`
M`.F@_/___Z/@````:*@!``#ID/S___^CY````&BP`0``Z8#\____H^@```!H
MN`$``.EP_/___Z/L````:,`!``#I8/S__XU,)`2#Y/#_<?Q5B>57B<]64^AY
M`@``@<.QK```48/L+(M!!(E%U(M!"(E%T&6A%````(E%Y#'`C4704(U%U%!1
MZ*K___^+@_@```"#Q`Q04/^S!`$``.@43P``BX,,`0``@\00@#@`#X0S`0``
MB[/P````@^P,_S;H,O[__X"(5@(```)8_S;H(_[__X/$$("(5@(```&+!XU0
M`X/`!(E5S#W___\_#X=]`0``@^P,P>`"4.BG_O__BW74BS^#Q!")P8F#,!,`
M`(L&B0&-@\:D__^)002+@_0.``")00B-@\FD__^)00R#_P$/CCX!``")3<B-
M1@2-41"--+Z-=@"+"(/`!(/"!(E*_#GP=?&+3<B#QP.#[`R-@ZA<___'!+D`
M````:@!1_W7,4/^S-!,``.B9^___@\0@B<:%P`^$E@```(/L#/^S-!,``(U]
MX.AK_?__B?J-@YNC___H_@$``(/$$(7`#X2%````@^P,_[,T$P``Z!7[___H
M@/S__X/$$(M%Y&4K!10````/A:8```"-9?")\%E;7E]=C6'\P^@:_/__B8,T
M$P``A<`/A(H```"#[`Q0Z&/\__^+L_````!:_S;HY?S__X/$$,:`"P8```#I
MFO[__X/L#/^S-!,``.AH^___@\00B<;I4O___XN#+!,``(7`=!&#[`Q0Z)L;
M``"#Q!#I8/___XGZC8-0H___Z$8!``")@RP3``"%P`^$1?___^O2Z*'\__^_
M!````.G<_O__Z&)-``"#[`QJ`>AH_?__9I!FD&:09I`Q[5Z)X8/D\%!44N@C
M````@<-HJ@``C8.8HO__4(V#.*+__U!15HV#.%/__U#H3OO___2+'"3#9I!F
MD&:09I"0BQPDPV:09I!FD&:09I!FD+@0T```/1#0``!T)+@`````A<!T&U6)
MY8/L%&@0T```_]"#Q!#)PXVT)@````!FD,.-M"8`````C;0F`````)"X$-``
M`"T0T```B<+!Z!_!^@(!T-'X=""Z`````(72=!=5B>6#[!!0:!#0``#_TH/$
M$,G#C70F`,.-M"8`````@#T@T````'4758GE@^P(Z&S____&!2#0```!R<.-
M=@##C;0F`````(VT)@````"0ZXYFD&:09I!FD&:09I!FD%575E/H)____X'#
M7ZD``(/L'(E$)`2)5"0,A<`/A)X```")P8N#"`$``(L`B40D"(7`#X2(````
M#[8!A,!T!#P]=3TQ]HM\)`B++X7M=">0@^P$5O]T)`Q5Z'+Z__^#Q!"%P'4'
M@'PU`#UT-(MO!(/'!(7M==J#Q!R)Z%M>7UW#B<X/MD8!@\8!A,!T!#P]=?$K
M="0$ZZZ-M"8`````9I"+1"0,B?DK3"0(C6PU`<'Y`HD(@\0<B>A;7E]=PXUV
M`(/$'#'M6XGH7E]=PXUT)@!55U:)QE/H5?[__X'#C:@``('LK````&6A%```
M`(F$))P````QP(7V=`6`/@!U(8N$))P```!E*P44````#X5&`0``@<2L````
M6UY?7<-FD(/L#%;HM_C__X/$$(G'A<!TS8V#"*/__XE$)`2-1"0<B40D"(/L
M#%?HP_C__X/$$(7`#X2X````@'@,+HU0#'4/@'H!`'3=C;0F`````&:0@'@,
M+@^$M@```(E4)`R#[`Q6Z+GY__^+5"0<B<6)%"2)5"0<Z*?Y__^-1`4"B00D
MZ$OY__^)Q5A:BU0D%%)6_W0D%&K_:@%5Z&/Z__^#Q!C_="005>C&^/__@\00
M@_C_=!"+1"0X)0#P```]`$```'1N@^P,5>B%^O__@\00@^P,5>BY]___@\00
M@^P,5^@-^/__@\00A<`/A4K___]FD(/L#%?H%_G__XDT).C?^/__@\00Z=;^
M__^-M"8`````@'H!+@^%0/___X!Z`@`/A`#____I,?___XVT)@````")Z.AY
M_O__ZY7HXDD``&:05HG&4^C'_/__@</_I@``@>R<````9:$4````B80DE```
M`#'`C40D%%!6Z#'Y__^#Q!"%P'4ZBU0D*('B`/```('Z`$```'0(@?H`H```
M=2*#[`AJ`E;HY?;__X/$$(7`#Y3`#[;`ZPJ-M"8`````D#'`BY0DC````&4K
M%10```!U"8'$E````%M>P^A020``55=6B<93Z#7\__^!PVVF``"![#`$``")
M5"009:$4````B80D(`0``#'`:/\#``"-@PZC__^-;"0D55#HH/C__X/$$(7`
M?DF`?`0;`(UX_W5_A?]T.X/L!%=J+U7H+_?__X/$$(7`="B+@_````"#[`S_
M,.CH]___5U564.BO]___@\0@ZRN-M"8`````C78`BX/P````@^P,_S#HP/?_
M_X/$#/]T)!!64.B2]O__@\00BX0D'`0``&4K!10```!U$X'$+`0``%M>7UW#
MC70F`(G'ZX'H=T@``(VT)@````!5B<575HG64^A3^___@<.+I0``@^PX9:$4
M````B40D*#'`,<"`.CT/E,`!QE;H/O?__X/$$(E$)`2-5"08B>CH[/O__X7`
M#X0$`0``@^P,B<=0Z!GW__^#Q!`Y1"0$#X;,````BT0D&,'@`HE$)`B+@P@!
M``")!"0/MD4`A,`/A)P!```\/0^$E`$``(GH9I`/ME`!@\`!A-)T!8#Z/77P
M*>B+#"2+?"0(@^P,BU0D$`,YC400`E#H9/;__X/$$(D'A<!T2HL,)(M\)`B+
M`8U-`8L4.`^V10"(`H3`=!T\/74*ZQ>-="8`A,!T#P^V`8/"`8/!`8@"/#UU
M[<8"/3'`#[8,!HA,`@&#P`&$R77QBT0D'&4K!10````/A1,!``"#Q"Q;7E]=
MPXVT)@````"0,<"-M@`````/MA0&B!0'@\`!A-)U\NO'C;0F`````)"+@P@!
M``"+$(D$)(LZA?\/A,(````Q_XVT)@````!FD(GX@\<!BPRZA<EU](T$A0P`
M``"+BR@3``"%R75CB50D#(/L#%#'@R@3```!````Z'SU__^#Q!")P87`#X1>
M____C02]`````(/L!(E$)`Q0BU0D%%)1B4PD'.B1]O__BT0D$(M,)!R#Q!")
M",=$N00`````B7PD&.F+_O__C78`@^P(4%+H!O3__XG!BT0D$(/$$(D(A<D/
MA`+___^-!+T`````B40D".O"C;8`````,<#I>_[__[@(````,?_I4/___^@X
M1@``C;0F`````)!64^@9^?__@<-1HP``@^P0B[/P````_S;H(_7__UC_-N@;
M]?__C9,<XO__4HV3':/___^S``$``%)0Z#'V__^#Q!3_-NCW]/__65YJ`(G"
MC8.CI/__4%"-@VAN__]0C8,YH___4%+H-?3__X/$)%M>PXVT)@````"-M"8`
M````D%/HFOC__X'#TJ(``(/L%(N#\````/\PZ*3T__^-DQSB__]2C9,=H___
M_[,``0``4E#HNO7__X/$*%O#C70F`)`QP,.-M"8`````C;8`````55=64^A'
M^/__@<-_H@``@>R\!```9:$4````B80DK`0``#'`BZPDT`0``(U4)"B+O"34
M!```C8-0H___Z-_X__^#[`AJ+XG&5>AR]/__@\00A<!T,XV#6:/__XGJZ([\
M__^)Z(N4)*P$``!E*Q44````#X6(`0``@<2\!```6UY?7<.-="8`D(/L#%7H
MS_/__XD\)(E$)"#HX_3__UJ-DV:C__]9B50D(%)0Z/#Q__^#Q!")QX7`=)R-
M@TZC__^);"0,BVPD&(E$)!R-@VBC__^)1"04C78`@#\`#X2_````A?9T%8/L
M"%=6Z('R__^#Q!"%P`^$?P```(/L#%?H7?/__X/$$(!\!_\O=1&-=@"#Z`&`
M?`?_+\8$!P!T\HM,)!"-1`@!/?\#``!_9(/L!(V#8Z3___]T)!#_="0<5U!H
M``0``&H!C;PDR````%?H[//__X/$&(U$)#105^A.\O__@\00A<!U$(M$)$@E
M`/```#T`@```=%>#[`A5:@#H'/'__X/$$(G'A<`/A4?___^+;"0,Z;O^__^-
MM@````"%]G0%@#XN=!>+?"0<N`$```#I9____XVT)@````!FD(!^`0!TL^OA
MC;0F`````)"#[`AJ`5?HY?#__X/$$(7`=9>)^HV#6:/__^@!^___@^P,5^B(
M\___@\00Z63^___H6T,``(VT)@````"-="8`BT0D!`^V$(G!A-)T$XUV`(/`
M`8#Z+P^V$`]$R(32=?")R,.-M"8`````C;8`````5E/H"?;__X'#0:```(/L
M!(MT)!"%]@^$M````(`^``^$JP```(/L#%;H\O'__X/$$(U$!O\YQG(.Z:X`
M``!FD(/H`3G&="6`."]T]#G&#X.8````@^@!.<9T$8UT)@"0@#@O=#"#Z`$Y
MQG7T@#XO=%^#[`R-@VBC__]0Z,#R__^#Q!"#Q`2)PHG06U[#C78`@#@O=0>#
MZ`$YQG+T*?`QTHU(`H'Y``0``'<;@\`!:``$``!05HVS*`\``%;H?^___X/$
M$(GR@\0$B=!;7L-FD(/L#(V#3J/__U#H8?+__X/$$(/$!(G"B=!;7L,YQG6E
MZ7?___^-M"8`````C70F`%575N@B$0``@<9`GP``4X/L3&6A%````(E$)#PQ
MP#'`QT0D&E]?14Z-7"04QT0D'E9?4$''1"0B4E]#3(NN"`$``(V^:J/__\=$
M)"9%04Y?QT0D*E\@("#'1"0N("`@(,=$)#(@("`@QT0D-B`@("!FB40D.HG:
MB?CH8O7__X7`="^+5"04BT4`C020BU`$B1"%TG3@C78`BU`(@\`$B1"%TG7T
MB=J)^.@S]?__A<!UT8NN"`$``(V^<Z/__XG:B?CH&O7__X7`="^+5"04BT4`
MC020BU`$B1"%TG3@C78`BU`(@\`$B1"%TG7TB=J)^.CK]/__A<!UT8NN"`$`
M`(V^>Z/__XG:B?CHTO3__X7`="^+5"04BT4`C020BU`$B1"%TG3@C78`BU`(
M@\`$B1"%TG7TB=J)^.BC]/__A<!UT8NN"`$``(V^A*/__XG:B?CHBO3__X7`
M="^+5"04BT4`C020BU`$B1"%TG3@C78`BU`(@\`$B1"%TG7TB=J)^.A;]/__
MA<!UT8VNBZ/__XN^"`$``(DL)(G:B>CH/_3__X7`=#2+5"04BP>-!)"+4`2)
M$(72=.&-M"8`````9I"+4`B#P`2)$(72=?2)VHGHZ`OT__^%P'7,BZX(`0``
MC;Z;H___B=J)^.CR\___A<!T+XM4)!2+10"-!)"+4`2)$(72=."-=@"+4`B#
MP`2)$(72=?2)VHGXZ,/S__^%P'71C890H___B[X(`0``B40D!(G%B=J)Z.BD
M\___A<!T,8M4)!2+!XT$D(M0!(D0A=)TX8VV`````(M0"(/`!(D0A=)U](G:
MB>CH<_/__X7`=<^-KJ>C__^+O@@!``");"0,B=J)Z.A6\___A<!T*XM4)!2+
M!XT$D(M0!(D0A=)TX8M0"(/`!(D0A=)U](G:B>CH*_/__X7`==6-KK&C__^+
MO@@!``");"0(B=J)Z.@.\___A<!T,XM4)!2+!XT$D(M0!(D0A=)TX8VT)@``
M``"0BU`(@\`$B1"%TG7TB=J)Z.C;\O__A<!US8NN"`$``(V^NZ/__XG:B?CH
MPO+__X7`="^+5"04BT4`C020BU`$B1"%TG3@C78`BU`(@\`$B1"%TG7TB=J)
M^.B3\O__A<!UT8NN"`$``(V^6:/__XG:B?CH>O+__X7`="^+5"04BT4`C020
MBU`$B1"%TG3@C78`BU`(@\`$B1"%TG7TB=J)^.A+\O__A<!UT8G:C8;%H___
MZ#KR__^)PH7`=`F+1"0(Z/OU__^)VHV&UJ/__^@>\O__B<*%P'0+C8;HH___
MZ-WU__^)VHV&\Z/__^@`\O__B<*%P'0LBT0D!.C!]?__BP0DC98?I/__Z+/U
M__^+1"0\92L%%````'5)@\1,6UY?7<.)VHV&`Z3__^C!\?__B<*%P'0+BT0D
M#.B"]?__Z[^!?"0K4$%27W6U@7PD+T-,14%UJV:!?"0S3CUUHHU4)#7KTNC(
M/0``C;0F`````)!3Z*KP__^!P^*:``"#[!AEH10```")1"0,BX/P#@``@_C_
M=!R+5"0,92L5%````'5`@\086\.-M"8`````C78`C50D"(V#IZ/__^@Q\?__
MB<(QP(72=!(/M@(\,`^5PH3`#Y7`#[;`(=")@_`.``#KL^A*/0``C;0F````
M`(UV`%/H*O#__X'#8IH``(/L".C\Z?__@^P,4.@CZO__@\00A<!T`HL`@\0(
M6\.-="8`D%575E/H]^___X'#+YH``(/L+&6A%````(E$)!PQP(U4)!B+?"1`
MC:LAI/__B>CHG?#__X7`=`>`.`")QG4BBT0D'&4K!10````/A:$```")^H/$
M+(GH6UY?7>E!]/__D(/L"%=0Z(;J__^#Q!"%P'0?BT0D'&4K!10```!U<H/$
M+%M>7UW#C;0F`````(UV`(/L#%?H=^O__XDT)(E$)!SH:^O__XM4)!R-1`("
MB00DZ`OK__^#Q`R)PHV#9J/__U90C8-CI/__5U!J_VH!4HE4)"SH&.S__X/$
M((M4)`R+1"0<92L%%`````^$8?___^@;/```C;0F`````(UT)@!55U93Z/?N
M__^!PR^9``"!["R!``"+A"1`@0``C7PD*(GZB40D$&6A%````(F$)!R!```Q
MP(V#/:3__\=$)#0`````B40D"(E$)"R-@TZC__^)1"0PC8/AH___B40D2(V#
M0J3__XE$)$R-@_ZC__^)1"10C8-*I/__B40D5(V#,:3__XE$)`R)1"0XC8-.
MI/__B40D/(V#4*/__\=$)%@`````QT0D0`````")1"08Z!SO__^%P'0)@#@`
M#X4O!```Z!KH__^#[`Q0Z$'H__^#Q!"%P`^$C@,``(LHA>T/A(0#``"#[`Q5
MZ"/J__^-1``!B00DZ,?I__^)1"0<#[9%`(/$$(3`=#^+="0,C8M7I/__B7PD
M%(GWB<Z-M@````"#[`P/ML"#Q0%05FK_:@%7@\<"Z+CJ__\/MD4`@\0@A,!U
MW8M\)!2-="1$C8/HH___ZP^-="8`D(M&!(/&!(7`="Z)^NAG[O__B<6%P'3I
M@#@`=.3HM_#__X7`=-N#[`Q5Z*KJ__^#Q!")PH7`=4.0BVPD"(UT)"SK%HVV
M`````(MN!(7M="F#Q@2`?0``="")Z.AY\/__A<!TY8/L#%7H;.K__X/$$(7`
M=-6)PNL#D#'2@^P,4HE4)"3H,>G__UG_="08B<;H)>G__XVL!@0$``")+"3H
MQNC__XE$)!B)QHV#7*3___]T)!Q0C8-HH___B40D)%"+5"0PC8-AI/__4E!J
M_VH!5NC$Z?__@\0H:,`!``!6Z$;I__^#Q!"#^/]U$NC)Z?__BP`]$0``0`^%
M?`(``(/L"(U$)&10_W0D%.@KZ?__@\00B<:%P'12@^P,_W0D%(M$)"#_,(V#
M"*7__U`Q[8N#]````&H!_S#H_>;__X/$((N$)!R!``!E*P44````#X7G!```
M@<0L@0``B>A;7E]=PXVT)@````!FD(M$)'@E`/```#T`0```=9Z+A"2`````
MB40D%.@`YO__.40D%'6(BT0D>"7_`0``/<`!```/A73___^#[`Q5Z+WG__^)
M^HG%C8,LI/__Z+[L__^#Q!"%P`^$^P$``(/L"%"+1"0<_S#HA//__XE$)"2#
MQ!"%P`^$W0$``(/L#/]T)"#HR>?__X/$$(G"@_@#=C^#[`B-@VJD__]0BT0D
M((U$$/R)5"0H4.BSYO__@\00A<!U'(M4)!R#^@0/A$`#``"+1"04@'P0^R\/
MA#$#``"+@_`.``"#^/\/A.$"``"-BZ>C__^%P`^$A`$``(V3'Z3__XG(C;NC
MI/__Z.#O___H*^7__U=0C8.#I/___W0D%/]T)!10:O]J`57H$.C__X/$((V#
MD:3__XE$)!#K-9#H&^C__X$X$0``0'4]Z.[D__^#Q@&#[`Q75E#_="0D_W0D
M)/]T)#!J_VH!5>C/Y___@\0P@^P(:,`!``!5Z$[G__^#Q!"#^/]TMH/L#/]T
M)!3H.N7__XM$)"B)ZNA/[___B2PDZ*?Z__^#Q!#I-?[__XVT)@````"+1"0,
MC70D..L0C;8`````BT8$A<!T,(/&!(GZZ$?K__^%P'3K@#@`=.:#[`Q0Z)7G
M__^#Q!")Q87`#X4\_/__BT8$A<!UT(/L#(VK-J3__VH-Z`'F__^)1"0<@\00
MN%,```#I./S__X/L"%#_="04BT0D(/\PC8/,I/__Z9C]__^-M"8`````@^P,
M4(E$)!CH`_K__XM$)!B)!"3H)^?__X/$$(G%Z8/]__^-="8`D(M$)!"+`(E$
M)!3I%/[__\>#\`X```````"#[`AJ`?]T)"#HT>3__X/$$(V+IZ/__XG'A<`/
MA%O^__]J`FK_:NY0Z`+D__^#Q`QJ!HVT)"0!``!65^@_Y?__@\00@+PD'`$`
M``!U#H"\)!T!``!##X2,`0``:@!J`&H`5^C(X___Z$,Q``")1"0@@\00B6PD
M%(G%ZQ*-="8`@^P$4%95Z+4Q``"#Q!"#[`1H`(```%97Z./D__^#Q!"%P'_<
MBVPD%(/L#%?H_^7__UA:_W0D&(VT).L```!6Z(PS``"-O"0#`0``B?*-@U>D
M__^)?"0@B?Z#Q!");"04B?V)QXET)!R)UHVV``````^V!H/L#(/&`5!7:O]J
M`56#Q0+HN.7__X/$(#MT)!!UWXML)!2+="0<C8.CI/__QH0D&P$```!0C8-T
MI/__5O]T)!3_="044&K_:@%5Z'[E__^#Q"#IP/W__XVV`````(V+IZ/__XGZ
MB<B)3"00Z#WI__^%P`^$C/[__P^V`(3`#X2!_O__/#`/A'G^___'@_`.```!
M````BTPD$.GL_/__BT0D$(M(!(7)#X3`_/__@^P,48E,)"#H,^3__X/$$(/X
M`P^&I_S__X/L"(V3;Z3__U*+3"0<C40!_%#H'^/__X/$$(M,)!"%P`]%3"04
MB4PD%.EX_/__@+PD'@$``$$/A6;^__^`O"0?`0``0P^%6/[__X"\)"`!``!(
M#X5*_O__@+PD(0$``$4/A3S^__]J`FK_:L97Z`3B__^#Q`QJ*597Z$CC__^-
M@Z.D__]0C8-TI/__5O]T)"3_="0D4&K_:@%5Z&?D__^#Q##IJ?S__^AZ-```
MC;0F`````(UV`%575E/H5^?__X'#CY$``(/L.&6A%````(E$)"@QP(NS\```
M`/\VZ%7C__]9_S:)Q^A+X___#[97:(U\)"B(4&F)^HV#BZ/__^CCY___@\00
MA<!T"8`X,0^$DP$``.CN\?__@^P,_S;H%./__XV3HJ3__VH#:@%24.BSX?__
M@\0@B<6%P'0ZBT`,@^P,BQ")5"08_S;HY^+__X/$#(V+I*3__U&+5"044E#H
MLN'__XM%#(/$$(LH]D4*0`^%<`$``(/L#/\VZ+;B__^-DZFD__]J`VH!4E#H
M5>'__X/$((G%A<!T/8GZC8-9H___Z#_G__^)PHL&A=*)5"0,#X3_````BTT,
M@^P,BRE0Z''B__^+5"0<@\0,4E50Z$+A__^#Q!"#[`S_-NA5XO__@\0,C9.K
MI/__:@%24.A#X/__B<58_S;H.>+__X/$#(V3P*3__U)54.@(X?__6O\VZ"#B
M__^)^L9`:0"-@U"C___HO^;__X/$$(F#+!,``(G&A<!T0(/L"&C``0``5NA2
MXO__@\00C5`!@_H!=@L]$0``0`^%IP```(M$)!QE*P44````#X6L````@\0L
M6UY?7<.-=@"#[`S_LS`3``#HDO;__X/$$(F#+!,``(G&A<!UHX/L#(V#7*7_
M_U#H).+__XUT)@"`>`$`#X1H_O__Z5[^__^0BY,P$P``BTT,@^P,BQ*+*8E4
M)!A0Z&;A__^+5"0<B>CH^^C__X/$$.GT_O__C78`@^P,_S;H1N'__UE:55#H
M;>'__X/$$.EU_O__4(N#,!,``%;_,(V#@*7__U#HK^'__^@*,@``C;0F````
M`(UV`%=64^CHY/__@<,@CP``@^PL9:$4````B40D*#'`BW0D/%;HN>[__X/$
M$`^V$(G'A-)T%8UT)@"0@\`!@/HO#[80#T3XA-)U\(N#\`X``(7V#Y7!@_C_
M=&B%P`^5P"'!A,EU'8M$)!QE*P44````#X61````@\0@6UY?PXUT)@"0@#X`
M=-Z#[`2-@URD__]J!%!7Z/G?__^#Q!"%P'7%BT0D'&4K!10```!U6H/$((GP
M6UY?Z=CE__^-M"8`````D(U4)!B-@Z>C__^(3"0/Z.WD__\/MDPD#X7`=`L/
MM@"$P'0$/#!U#\>#\`X```````#I;?___\>#\`X```$```#I6O___^CV,```
MBS0DPV:055=64XG#@>P,`P``B40D5(VL)(````!EH10```")A"3\`@``B=B)
M="00C9PD``$``(E\)!2)WXU0.(U$)'B)1"0(B40D&(VT)@````"-=@"+2@2+
M`L=%_`````"#Q1#'1?0`````@\((B<L/R(E%Z(G(P>L(P>@8B0PD@>,`_P``
MQT0D!``````)V(L<)(G9P>,(P>$8"<B)V8'A``#_``G(B47P.?UUIXM4)`B+
M1"08@<(``@``B<6)%"2-="8`BU5HBT5L@\4(QT5\`````#-5.#-%/#-5"#-%
M##-5^#-%_(G'B=&)T`'1#ZSX'PG!B4UX.RPD=<B+;"14BW44BT4`BTT(BWT<
MBU4$BUT,B70D!(MU&(E,)#")P8E\)`R+?2`/K-$;B70D"(G&B5PD-,'F!8M=
M$(MM)`G.B7PD6(E4)"R+?"18,=(#?"1XB6PD7(GYBVPD7!-L)'R)'"2!P9EY
M@EJ)1"0HB>N)\(/3``'(BSPDBTPD,!':B40D$(E4)!2+5"0(,=<ASXGZBWPD
M"(M$)!#'1"0D`````(ML)#3'1"0\`````#'ZBWPD,,=$)$0``````=")^HG^
MB40D((L$),'B'@^L[@*+;"0DB=.+5"0("?,#E"2`````B5PD.(MT)#B)T8'!
MF7F"6HM4)`2)7"08,<:+1"0HBQPDB?>)UB-T)"R+5"0L(<>)="00B?Z+/"0Q
M_HM\)"")\(G^`<B)^8GO#ZSN&\'A!8ET)!"+;"00P>\;B7PD%`G-QT0D%```
M``")[@'&BT0D*(ET)!"+="0$B<$/K-`"P>$>B<T)Q8EL)$`#G"2(````B=@3
MM"2,````BUPD&`69>8):B?*+="0@BWPD%(/2`#'K(=XS="0X,=L!\(MT)!`1
MVHM<)"")1"08B?$/K/X;B50D','A!8GRBW0D),'O&PG*`50D&(G:BTPD.`^L
M\P+!XAZ+="08B7PD3`G:`XPDD````,=$)!P`````B<B+?"0<B?&)5"1(!9EY
M@EHQU2-L)!`S;"1``>B)_8GWP>$%#ZSO&\'M&XE4)&")?"0@B6PD)(ML)"#'
M1"1,``````G-QT0D)`````")[@'&B70D((M\)!"+;"04BTPD0,=$)#P`````
MB?N+="1@P>,>#ZSO`HG:BUPD1`GZ`XPDF````!.<))P```")R(E4)#B)U8G:
M!9EY@EJ+?"0D@](`,>XC="08,W0D2#';`?"+="0@$=J+7"08B40D$(GQ#ZS^
M&XE4)!3!X06)\HMT)!S![QL)R@%4)!")VHM,)$@/K/,"P>(>B7PD1`G:`XPD
MH````,=$)!0`````B<B)5"1`!9EY@EJ)5"1@,=4C;"0@QT0D1``````S;"0X
MBW0D$(M\)!0!Z,=$)$P`````B?V)]XGQ#ZSO&\'M&XE\)!C!X06+?"0@B6PD
M'(ML)!B)^\=$)!P`````"<V+3"0XB>Z+;"0D`<;!XQX/K.\"B=J)="08BUPD
M/`GZ`XPDJ````(MT)&`3G"2L````B<B)U8E4)$@%F7F"6HG:BWPD'(/2`#'N
M(W0D$#-T)$`QVP'PBW0D&!':BUPD$(E$)"")\0^L_AN)5"0DP>$%B?*+="04
MP>\;"<H!5"0@B=K!XAX/K/,"B7PD/`G:QT0D)`````")5"0XQT0D/`````"+
M3"1``XPDL````(MT)"")5"1@BWPD)(G(QT0D1``````%F7F"6C'5(VPD&#-L
M)$@!Z(G]B?>)\0^L[QO![1N)?"00P>$%BWPD&(EL)!2+;"00B?O'1"04````
M``G-BTPD2(GNBVPD'`'&P>,>#ZSO`HG:B70D$(M<)$P)^@.,)+@```"+="1@
M$YPDO````(G(B=6)5"1`!9EY@EJ)VHM\)!2#T@`Q[B-T)"`S="0X,=L!\(MT
M)!`1VHE$)!B)\0^L_AN)5"0<P>$%P>\;B?()RHE\)$P!5"08BUPD((MT)"2+
M3"0XQT0D'`````")VHM\)!S'1"1,``````^L\P+!XAZ+="08QT0D/``````)
MV@.,),````")R(GQB50D2`69>8):,=4C;"00,VPD0`'HB?V)]\'A!0^L[QO!
M[1N)5"1@B7PD((M\)!");"0DBVPD((G[QT0D)``````)S8M,)$")[HML)!0!
MQL'C'@^L[P*)VHET)""+7"1$"?H#C"3(````BW0D8!.<),P```")R(G5B50D
M.`69>8):B=J#T@`Q[B-T)!@S="1(,=L!\(E$)!"+="0@$=J+?"0DBUPD&(E4
M)!2)\<=$)!0`````#ZS^&\'A!<=$)$P`````B?*+="0<P>\;"<H!5"00B=J+
M3"1(#ZSS`L'B'HMT)!")?"1$"=H#C"30````BWPD%,=$)$0`````B<B)\8E4
M)$`%F7F"6C'5(VPD(#-L)#@!Z(G]B??!X04/K.\;P>T;B50D8(E\)!B+?"0@
MB6PD'(ML)!B)^\=$)!P`````"<V+3"0XB>Z+;"0D`<;!XQX/K.\"B=J)="08
MBUPD/`GZB50D2`.,)-@```")U1.<)-P```"+="1@B<@%F7F"6HG:BWPD'(/2
M`#'N(W0D$#-T)$`QVP'PBW0D&!':BUPD$(E$)"")\0^L_AN)5"0DP>$%B?*+
M="04P>\;"<H!5"0@B=J+3"1`#ZSS`L'B'HMT)"")?"0\"=H#C"3@````QT0D
M)`````")R(M\)"2)\8E4)#@%F7F"6C'5(VPD&#-L)$@!Z(G]B??!X04/K.\;
MP>T;B50D8(E\)!");"04BVPD$,=$)#P`````"<V)[@'&B70D$,=$)!0`````
MBWPD&(ML)!R+3"1(QT0D1`````")^XMT)&#!XQX/K.\"B=J+7"1,"?H#C"3H
M````$YPD[````(G(B50D0(G5B=H%F7F"6HM\)!2#T@`Q[B-T)"`S="0X,=L!
M\(MT)!`1VHM<)"")1"08B?$/K/X;B50D','A!8GRBW0D),'O&PG*`50D&(G:
MBTPD.`^L\P+!XAZ)?"1,"=H#C"3P````QT0D'`````")R(E4)$@%F7F"6HE4
M)&`QU2-L)!#'1"1,`````#-L)$"+="08BWPD'`'HQT0D/`````")_8GWB?$/
MK.\;P>T;B7PD(,'A!8M\)!");"0DBVPD((G[QT0D)``````)S8M,)$")[HML
M)!0!QL'C'@^L[P*)VHET)""+7"1$"?H#C"3X````BW0D8!.<)/P```")R(G5
MB50D.`69>8):B=J+?"0D@](`,>XC="08,W0D2#';`?"+="0@$=J+7"08B40D
M$(GQ#ZS^&XE4)!3!X06)\HMT)!S![QL)R@%4)!")VL'B'@^L\P*)?"1$"=K'
M1"04`````(E4)$#'1"1$`````(M,)$@#C"0``0``BW0D$(E4)$B+?"04B<@%
MF7F"6C'5(VPD(#-L)#@!Z(G]B?>)\0^L[QO![1N)?"08P>$%BWPD((EL)!R+
M;"08B?O'1"0<``````G-BTPD.(GNBVPD),=$)"0``````<;!XQX/K.\"B=J)
M="08BUPD/`GZ`XPD"`$``(MT)$@3G"0,`0``B<B)U8E4)"`%F7F"6HG:@](`
M,>XC="00,W0D0(GQ,=L!P8M$)!@1TXM4)!R)3"0XB<:)7"0\BTPD.`^LT!O!
MY@6)PXM$)!`)\P'9,?^)SHE,)$B+5"04B<'!X1['1"04``````^LT`*)RXM4
M)$`)PP.4)!`!``")T(M4)!R)7"0X!9EY@EHQW2-L)!@S;"0@B>F+7"0X`<&)
M\,'@!8E$)!")\(ML)!`/K/@;B40D0(M$)!@+;"1``>F)3"00B4PD0(G!#ZS0
M`HM4)"#!X1Z)S8M,)"0)Q0.4)!@!```3C"0<`0``B=")R@6AZ]EN@](`,>N)
M1"08BT0D$(E4)!R+5"1(,=HQVXG1`TPD&(M4)!2)3"08B<$37"0<P>$%B5PD
M'(E,)"")T8G"BUPD(`^LRAN+3"08QT0D'`````")5"1("UPD2`'9BYPD(`$`
M`(E,)$B)3"08B?$/K/X"P>$>B?")SHM,)#@)QH'#H>O9;HGWB[0D)`$``(G8
MB7PD.(/6`#';`<B)\HG^BWPD0!':,>XQVS'WB?D!P8M$)!@1TXM4)!R)3"0@
MB<:+3"0@B5PD)`^LT!O!Y@6+5"04B<.+1"00"?,!V3'_B<Z)3"1`B<$/K-`"
MP>$>BY0D*`$``(G+BXPD+`$```G#@<*AZ]EN@]$`B=")7"0@,=N)R@'H$=J+
M7"0X,UPD((E$)!")5"04BU0D2(GP,=J)T0-,)!#!X`6)1"00B?`/K/@;B40D
M2(ML)!"+1"08"VPD2,=$)!0``````>F+5"0<B4PD$(E,)$B)P0^LT`*+E"0P
M`0``P>$>B<V+C"0T`0``"<6!PJ'KV6Z+1"0X@]$`B<N)T3'2`<@1VHM<)"")
M1"08B50D'(M4)$`QZXM$)!`QVC';B=$#3"08BU0D%(E,)!B)P1-<)!S!X06)
M7"0<B4PD.(G1B<*+7"0X#ZS*&XM,)!C'1"0<`````(E4)$`+7"1``=F+G"0X
M`0``B4PD0(E,)!B)\0^L_@+!X1Z)\(G."<:+1"0@@<.AZ]ENB?>+M"0\`0``
MB7PD.(/6`#'2`=@1\HG^BWPD2#';,>XQ]XGY`<&+1"08$=.+5"0<B4PD((G&
MBTPD((E<)"0/K-`;P>8%BU0D%(G#BT0D$`GS`=DQ_XG.B4PD2(G!#ZS0`L'A
M'HN4)$`!``")RXN,)$0!```)PX'"H>O9;HGH@]$`B5PD((G+B=$QT@'($=J+
M7"0X,UPD((E$)!")5"04BU0D0(GPQT0D%``````QVHG1`TPD$,'@!8M4)!R)
M1"00B?"+;"00#ZSX&XE$)$"+1"08"VPD0`'IB4PD0(E,)!")P0^LT`*+E"1(
M`0``P>$>B<V+C"1,`0``"<6!PJ'KV6Z+1"0X@]$`B<N)T3'2`<@1VHE$)!B)
M5"0<BUPD((M4)$B+1"00,>LQVC';B=$#3"08BU0D%(E,)!B)P1-<)!S!X06)
M7"0<B4PD.(G1B<*+7"0X#ZS*&XM,)!C'1"0<`````(E4)$@+7"1(`=F+G"10
M`0``B4PD&(E,)$B)\0^L_@+!X1Z)\(G."<:+1"0@@<.AZ]ENB?>+M"14`0``
MB7PD.(/6`#'2`=@1\HG^BWPD0#';,>XQ]XGY`<&+1"08$=.+5"0<B4PD((G&
MBTPD((E<)"0/K-`;P>8%BU0D%(G#BT0D$`GS`=DQ_XG.B4PD0(G!#ZS0`L'A
M'HN4)%@!``")RPG#@<*AZ]ENB>B)7"0@BXPD7`$``(/1`(G+B=$QT@'($=J+
M7"0X,UPD((E$)!")5"04BU0D2(GPQT0D%``````QVHG1`TPD$,'@!8M4)!R)
M1"00B?"+;"00#ZSX&XE$)$B+1"08"VPD2`'IB4PD$(E,)$B)P0^LT`*+E"1@
M`0``P>$>B<V+C"1D`0``"<6!PJ'KV6Z+1"0X@]$`B<N)T3'2`<@1VHM<)"")
M1"08B50D'(M4)$`QZXM$)!`QVC';B=$#3"08BU0D%(E,)!B)P1-<)!S!X06)
M7"0<B4PD.(G1B<(/K,H;B50D0(M,)!B+7"0X"UPD0,=$)!P``````=F+G"1H
M`0``B4PD0(E,)!B)\0^L_@+!X1Z)\(G."<:+1"0@@<.AZ]ENB?>+M"1L`0``
MB7PD.(/6`#'2`=@1\HG^BWPD2#';,>XQ]XGY`<&+1"08$=.+5"0<B4PD((G&
MBTPD((E<)"0/K-`;P>8%BU0D%(G#BT0D$`GS`=DQ_XG.B4PD2(G!#ZS0`L'A
M'HN4)'`!``")RXN,)'0!```)PX'"H>O9;HGH@]$`B5PD((G+B=$QT@'($=J+
M7"0X,UPD((E$)!")5"04BU0D0(GP,=J)T0-,)!#!X`6)1"00B?"+;"00#ZSX
M&XE$)$`+;"1`BT0D&`'IBU0D',=$)!0`````B4PD$(E,)$")P0^LT`*+E"1X
M`0``P>$>B<V+C"1\`0``"<6!PJ'KV6Z+1"0X@]$`B<N)T3'2`<@1VHM<)"")
M1"08B50D'(M4)$@QZXM$)!`QVC';B=$#3"08BU0D%(E,)!B)P1-<)!S!X06)
M7"0<B4PD.(G1B<*+7"0X#ZS*&XM,)!C'1"0<`````(E4)$@+7"1(`=F+G"2`
M`0``B4PD2(E,)!B)\0^L_@+!X1Z)\(G."<:+1"0@@<.AZ]ENB?>+M"2$`0``
MB7PD.(/6`#'2`=@1\HG^BWPD0#';,>XQ]XGY`<&+1"08$=.+5"0<B4PD((G&
MBTPD((E<)"0/K-`;P>8%BU0D%(G#BT0D$`GS`=DQ_XG.B4PD0(G!#ZS0`L'A
M'HN4)(@!``")RXN,)(P!```)PX'"H>O9;HGH@]$`B5PD((G+B=$QT@'($=J+
M7"0X,UPD((E$)!")5"04BU0D2(GPQT0D%``````QVHG1`TPD$,'@!8M4)!R)
M1"00B?"+;"00#ZSX&XE$)$B+1"08"VPD2`'IB4PD2(E,)!")P0^LT`*+E"20
M`0``P>$>B<V+C"24`0``"<6!PJ'KV6Z+1"0X@]$`B<N)T3'2`<@1VHE$)!B)
M5"0<BUPD((M4)$"+1"00,>LQVC';B=$#3"08BU0D%(E,)!B)P1-<)!S!X06)
M7"0<B4PD.(G1B<*+7"0X#ZS*&XM,)!C'1"0<`````(E4)$")\@M<)$`!V0^L
M_@*+G"28`0``P>(>B?")3"08B=:)3"0X"<:+1"0@@<.AZ]ENB?>+M"2<`0``
MB7PD0(/6`#'2`=@1\HG^BWPD2#';,>XQ]XGYBWPD%`'!BT0D&!'3BU0D'(E,
M)"")QHE<)"2+3"0@#ZS0&\'F!<=$)"0`````B<.)Z`GSBW0D$`'9B4PD2(E,
M)"")\0^L_@+!X1Z)RPGSB=^+G"2@`0``BW0D.,=$)#P`````BU0D)(E\)!"!
MPZ'KV6X!V(M<)$`Q^XM\)!PQWHN<)*@!``")\0'!BT0D((G&#ZS0&XE$)#C!
MY@4+="0X`?&+="08B4PD.(E,)&")\0^L_@+!X1Z)\(G.BTPD0`G&@<.AZ]EN
MB?6+M"2L`0``B=B);"1`@]8`,=L!R(GRBW0D2!':BUPD$#'K,=XQVXGQ`<&+
M1"0X$=.+5"0\B4PD&(G&B5PD'(G7P>8%QT0D'``````/I,<%B?.)_HG'BT0D
M(`^LUQN+5"0DB70D3(G!B<8)^P%<)!@/K-8"P>$>B?")S@G&B70D((GUQT0D
M)`````"+G"2P`0``B[0DM`$``(M,)!"!PZ'KV6Z+?"1@@]8`B=@QVXGR`<B+
M="08$=J+7"1`B?$QZS'?,=L!^(M\)!P1VHE$)!#!X06+1"00#ZS^&XE4)!3!
M[QN+G"2\`0``B?*+="0XB7PD3(M\)#P)RL=$)!0`````B?$!T,=$)#P`````
M#ZS^`L'A'HE$)!"+1"1`"?&+="08B<^)3"0XBXPDN`$``(E\)$B!P=R\&X^#
MTP`QT@'(BTPD(!':(TPD.`G]B40D0"'UBT0D$(M\)!R)5"1$B<H)ZHG1BU0D
M%`-,)$`/I,(%P>`%B40D&(E4)!R+5"04BT0D$(ML)!C'1"0<`````(M<)$@/
MK-`;P>H;B40D0`ML)$")5"1$B>B)\@'(#ZS^`HM\)"3'1"1$`````,'B'HE$
M)!B+1"00"?*+="0@"=.)U8E4)$"+5"0X(=@QVR'J"=`#M"3``0``$[PDQ`$`
M`(G!B?")^HM\)!0%W+P;CX/2``'!BT0D&!'3BU0D'(E,)$B)7"1,B<&)T\'A
M!0^DPP6)3"0@BW0D((E<)"2)PP^LTQO'1"0D``````G>B?"+="00`T0D2(E$
M)"")\<'A'HG(B?$/K/D"B<()RHE4)$@)U<=$)$P`````BUPD0"-L)!B+="0X
MB50D8"'3BWPD((M4)&`)W0.T),@!``"+7"0<QT0D'`````")\(G^B?D%W+P;
MCP'HBVPD),'A!0^L[AN)[XET)!"+;"00P>\;B7PD%`G-BTPD&`'H,?^)QHG(
M#ZS9`C';P>`>B<6+1"0@"<T)ZHEL)!@AT(M4)$@AZ@G0BU0D1(G!BT0D0`.$
M)-`!```3E"34`0``!=R\&X^#T@`!P8GP$=.)^L'@!8E,)#@/I/(%B<&)7"0\
MB?")TXGZ#ZS0&XE<)$3!ZAN)1"00BUPD$(E4)!0)RXG8`T0D.(E$)!#'1"04
M`````(M,)""+7"0DQT0D/`````")R,'@'@^LV0(QVXG"BT0D2`G*BTPD&`G5
MB50D."'1(?6)5"1@BU0D3`G-`X0DV`$``!.4)-P!``")Z07<O!N/@](``<&+
M1"00$=.)3"1(BU0D%(G!B5PD3,'A!8G3B4PD((G1B<(/I,,%#ZS*&\'I&XE<
M)"2+7"0@B50D0`M<)$")3"1$B?&)V`-$)$C!X1Z+7"1@BU0D.(E$)"")R(GQ
MQT0D)``````/K/D"B<6+1"00BWPD'`G-QT0D1``````)ZR'JB6PD0"'8,=N)
MQ@G6B?&+="08`[0DX`$``(GP$[PDY`$``(MT)"")^@7<O!N/BWPD)(/2``'(
MB?$1V@^L_AN)1"08BT0D&(E4)!S!X06)\L'O&PG*BTPD$(M<)!2)?"1,`="+
M="0@BWPD),=$)!P`````B40D&(G(#ZS9`HM<)$#!X!['1"1,`````(G"BT0D
M.`G*"=4ATXE4)$@A]8E4)&"+5"0<"=T#A"3H`0``B>D%W+P;CP'!BT0D&`^D
MP@7!X`6)1"00BT0D&(E4)!2+5"0<BVPD$`^LT!O!ZAN)1"0@"VPD((E4)"2)
MZ(GR`<C!XAXQVXE$)!`/K/X"B=6+5"1@"?6+1"08BW0D0,=$)!0`````">J+
M?"1$B6PD."'0BU0D2,=$)#P`````(>H)T`.T)/`!```3O"3T`0``B<&)\(GZ
MBWPD'`7<O!N/QT0D'`````"#T@`!P8M$)!`1TXM4)!2)3"1`B5PD1(G!B=/!
MX04/I,,%B4PD((MT)"")7"0DB<,/K-,;QT0D)``````)WHM<)#B)\(MT)!@#
M1"1`B40D((GQP>$>B<B)\8MT)$@/K/D"B<()RB'3"=4C;"00B50D&`G=`[0D
M^`$``(E4)&")\(M\)""+7"04!=R\&X^+5"1@`>B+;"0DB?Z)^<'A!0^L[AN)
M[XET)$"+;"1`P>\;B7PD1`G-BTPD$,=$)$0``````>@Q_XG&B<@/K-D",=O!
MX!Z)Q8M$)"`)S0GJB6PD0"'0BU0D&"'J"="+5"0\B<&+1"0X`X0D``(``!.4
M)`0"```%W+P;CX/2``'!B?`1TXGZP>`%B4PD.`^D\@6)7"0\B<&)\(G3B?K'
M1"0\``````^LT!N)7"1,P>H;B40D$(M<)!")5"04"<N+3"0@QT0D%`````")
MV`-$)#B+7"0DB40D$(G(P>`>#ZS9`C';B<()RHE4)#@)U8E4)&"+3"1`(?6+
M1"08(=&+5"0<"<T#A"0(`@``$Y0D#`(``(GI!=R\&X^#T@`!P8M$)!`1TXE,
M)$B+5"04B<&)7"1,P>$%B=/'1"1,`````(E,)!B)T8G"#Z3#!0^LRAO!Z1N)
M7"0<BUPD&(E4)"`+7"0@B4PD)(GQB=@#1"1(P>$>BUPD8(M4)#B)1"0@B<B)
M\<=$)"0`````#ZSY`HG%BT0D$(M\)$0)S0GK(>J);"1((=@QVXG&"=:)\8MT
M)$`#M"00`@``B?`3O"04`@``B?H%W+P;CX/2``'($=J)1"08B50D'(MT)""+
M?"0DBT0D&,=$)!P`````B?&+7"04QT0D/``````/K/X;P>$%B?+![QN+="0@
M"<J+3"00B7PD1`'0BWPD),=$)$0`````B40D&(G(#ZS9`HM<)$C!X!Z)PHM$
M)#@)R@G5(=.)5"1@(?6)5"1`BU0D'`G=`X0D&`(``(GI!=R\&X\!P8M$)!@/
MI,(%P>`%B40D$(M$)!B)5"04BU0D'(ML)!#'1"04``````^LT!O!ZAN)1"0@
M"VPD((E4)"2)Z(GR`<C!XAXQVP^L_@*)U8M4)&")1"00"?6);"0XBT0D&`GJ
MBW0D2(M\)$PAT(M4)$`AZ@G0`[0D(`(``!.\)"0"``")P8GPB?J+?"0<!=R\
M&X_'1"0<`````(/2``'!BT0D$!'3BU0D%(E,)$B)7"1,B<&)T\'A!0^DPP6)
M3"0@BW0D((E<)"2)PP^LTQO'1"0D``````G>BUPD.(GPBW0D&`-$)$B)1"0@
MB?'!X1Z)R(GQBW0D0`^L^0*)PHM\)"`)RB'3"=4C;"00B?D)W0.T)"@"``")
M5"08B?")_HE4)$@%W+P;CP'HBVPD),'A!8GO#ZSN&\'O&XET)$")?"1$BVPD
M0(M<)!2+5"1(QT0D1``````)S8M,)!`!Z#'_B<:)R`^LV0(QV\'@'HG%BT0D
M(`G-">J);"1`(="+5"08(>H)T(M4)#R)P8M$)#@#A"0P`@``$Y0D-`(```7<
MO!N/@](``<&)\!'3B?K!X`6)3"0X#Z3R!8G!B5PD/(GPB=.)^@^LT!N)7"1,
MP>H;B40D$(M<)!")5"04"<N+3"0@QT0D%`````")V`-$)#B+7"0DQT0D)```
M``")1"00B<C!X!X/K-D",=N)PHM$)!@)RHM,)$`)U8E4)"`AT2'UB50D2(M4
M)!P)S0.$)#@"```3E"0\`@``B>D%W+P;CX/2``'!BT0D$!'3B4PD8(M4)!2)
MP8E<)&3!X06)TXE,)!B)T8G"#Z3#!0^LRAO!Z1N)7"0<BUPD&(E4)#@+7"0X
MB4PD/(GQB=@#1"1@P>$>BUPD2(M4)"")1"08B<B)\<=$)!P`````#ZSY`HG%
MBT0D$(M\)$0)S<=$)#P`````">LAZHEL)#@AV#';B<8)UHGQBW0D0`.T)$`"
M``")\!.\)$0"``"+="08B?H%W+P;CXM\)!R#T@`!R(GQ$=H/K/X;B40D0(M$
M)$#!X07![QN)5"1$B?()RHE\)$R+3"00`="+7"04,?_'1"0D`````(G&B<C'
M1"04`````,'@'@^LV0*+7"0XQT0D1`````")PHM$)"`)RB'3"=4C;"08B50D
M$`G=`X0D2`(``(E4)$B)Z07<O!N/BU0D'`'!B?#!X`6)1"0@B?"+;"0@#ZSX
M&XE$)$"+1"08"VPD0`'IB4PD((E,)&")P0^LT`*+5"1(P>$>B<L)PPG:B=V)
M7"1`BUPD$(G0BU0D/"'K(?`)V#';B<&+1"0X`X0D4`(``!.4)%0"```%W+P;
MCX/2``'!BT0D(!'3B4PD&(M4)"2)P8E<)!S!X06)3"0XB=&)PHM<)#@/K,H;
MBTPD&,=$)!P`````B50D2`M<)$@!V8M4)"3'1"04`````(E,)$B)3"08B?$/
MK/X"BWPD&,'A'HGPB<Z+3"00"<8#C"18`@``B<B)="0XBUPD.`76P6+*,?6+
M="1@,>Z+;"0<B?$!P8GX#ZSO&\'@!8E$)!"+="00BT0D(`G^`?&)3"00B<Z)
MP0^LT`+!X1Z+5"1`B<T)Q0.4)&`"``")T(EL)$"+5"04!=;!8LHQZXML)$@Q
MW8GI`<&+1"00P>`%B40D((M$)!"+;"0@#ZS0&XE$)$@+;"1(BT0D&`'IBU0D
M',=$)"0`````B4PD8(E,)"")P0^LT`*+E"1H`@``P>$>QT0D'`````")RXN,
M)&P"```)PX'"UL%BRH/1`(G0B=TQVXG*BTPD.(EL)$@!R!':BUPD0#'KB=TQ
MVS'UB>D!P8M$)"`1TXM4)"2)QHG'BT0D$,'F!0^LUQLQTHET)!B+="08"?Z+
M?"0<`?&)QA'3P>8>BU0D%(E,)!B)3"1HB?&)Q@^LU@*)7"1LBYPD<`(``(GP
MB<Z+3"1`"<:!P];!8LJ)]8MT)$B)V`'(B6PD.#'NBVPD8#'UBW0D&(GIB?T!
MP8GPB??!X`4/K.\;B40D$(MT)!"+1"0@"?X!\3'_B4PD8(M4)"2)SHG!P>$>
M#ZS0`HN4)'@"``")RXN,)'P"```)PXM$)$B!PM;!8LJ)W8/1`(G+B=$QT@'(
M$=J+7"0XB40D$(GPB50D%(M4)&@QZS':,=N)T0-,)!`37"04P>`%B4PD$(G!
MB?"+5"0<#ZSX&XE<)!2)1"0@BUPD((M$)!C'1"04``````G+BTPD$`'9B4PD
M((E,)!")P0^LT`*+E"2``@``P>$>B<N+C"2$`@``"<.!PM;!8LJ+1"0X@]$`
MB5PD0(G+B=$QT@'($=J+7"1`B40D&(E4)!R+5"1@,>LQVC';B=$#3"08$UPD
M'(E,)!B+1"00BU0D%(E<)!R)P<=$)!P`````P>$%QT0D)`````")3"0XB=&)
MPHM<)#@/K,H;BTPD&(E4)$@+7"1(`=F+G"2(`@``BU0D%(E,)$B)3"08B?$/
MK/X"P>$>B?")S@G&@</6P6+*B>B+;"0@B?>+="1``=B)?"0XBUPD.#'^BWPD
M&#'UB>F+;"0<`<&)^,'@!0^L[QN)1"0@BW0D((M$)!`)_@'QB4PD((G.B<$/
MK-`"P>$>BU0D)(G-BXPDD`(```G%BT0D0('!UL%BRHEL)$`!R#'KBVPD2#'=
MB>D!P8M$)"#!X`6)1"00BT0D(`^LT!N)1"1(BT0D&(ML)!`+;"1(QT0D%```
M```!Z8M4)!S'1"0<`````(E,)!")3"1(B<$/K-`"BU0D%,'A'HG+BXPDF`(`
M``G#BT0D.(G=B5PD.(M<)$"!P=;!8LH!R#'KB=V+G"2@`@``,?6)Z0'!BT0D
M$(G&B<>+1"0@P>8%#ZS7&XM4)"2)="08BW0D&`G^BWPD'`'QB<;!YAZ)3"08
MB4PD8(GQB<8/K-8"BU0D%(GPB<X)QHM$)$"!P];!8LJ)]8MT)#@!V(EL)"`Q
M[HML)$@Q]8MT)!B)Z8G]`<&)\(GWP>`%#ZSO&XE$)$"+="1`BT0D$`G^`?$Q
M_XG.B4PD0(G!#ZS0`L'A'HN4)*@"``")RXN,)*P"```)PX'"UL%BRHM$)#B#
MT0")W8G+B=$QT@'($=J+7"0@B40D$(GPB50D%(M4)&`QZS':,=N)T0-,)!`3
M7"04P>`%B4PD$(G!B?"+5"0<#ZSX&XE<)!2)1"0XBUPD.(M$)!C'1"04````
M``G+BTPD$`'9B4PD2(E,)!")P0^LT`*+E"2P`@``P>$>B<N+C"2T`@``"<.!
MPM;!8LJ+1"0@@]$`B5PD.(G+B=$QT@'($=J+7"0XB40D&(E4)!R+5"1`,>LQ
MVC';B=$#3"08$UPD'(E,)!B)7"0<BT0D$(M4)!3'1"0<`````(G!QT0D)```
M``#!X06)3"0@B=&)PHM<)"`/K,H;P>D;B4PD1(M,)!B)5"1`"UPD0`'9BYPD
MN`(``(M4)!2)3"1@B4PD&(GQ#ZS^`L'A'HGPB<X)QH'#UL%BRHGHBVPD2(GW
MBW0D.`'8B7PD0(M<)$`Q_HM\)!@Q]8GIBVPD'`'!B?C!X`4/K.\;B40D((MT
M)""+1"00"?X!\8E,)"")SHG!#ZS0`L'A'HM4)"2)S8N,),`"```)Q8M$)#B!
MP=;!8LJ);"0X`<@QZXML)&`QW8GI`<&+1"0@P>`%B40D$(M$)"`/K-`;B40D
M2(M$)!B+;"00"VPD2,=$)!0``````>F+5"0<QT0D'`````")3"1(B4PD$(G!
M#ZS0`HM4)!3!X1Z)RXN,),@"```)PXM$)$")W8E<)$"+7"0X@<'6P6+*`<@Q
MZXG=BYPDT`(``#'UB>D!P8M$)!")QHG'BT0D(,'F!0^LUQN+5"0DB70D&(MT
M)!@)_HM\)!P!\8G&P>8>B4PD&(E,)&")\8G&#ZS6`HM4)!2)\(G."<:+1"0X
M@</6P6+*B?6+="1``=B);"0X,>Z+;"1(,?6+="08B>F)_0'!B?")]\'@!0^L
M[QN)1"0@BW0D((M$)!`)_@'Q,?^)SHE,)$B)P0^LT`+!X1Z+E"38`@``QT0D
M)`````")RXN,)-P"```)PX'"UL%BRHM$)$"#T0")W8G+B=$QT@'($=J+7"0X
MB40D$(GPB50D%(M4)&`QZS':,=N)T0-,)!`37"04P>`%B4PD$(G!B?`QT@^L
M^!N)7"04B40D((M<)"`)RXM,)!")V(M<)!0!P8M$)!@1TXM4)!R)3"1@B4PD
M((G!P>$>#ZS0`HN4).`"``")7"1DB<N+C"3D`@``"<.!PM;!8LJ#T0")T(E<
M)$`QVXG*BTPD.`'($=J+7"1`B40D$(E4)!2+5"1(,>LQVC';B=$#3"00$UPD
M%,=$)!P`````BT0D((M4)"2)3"00B5PD%(G!P>$%B4PD&(G1B<*+7"08#ZS*
M&XM,)!")5"0X"UPD.#'2B=B+7"04`<$1TXE,)!B+5"0DB4PD2(GQB5PD3(G[
MP>$>#Z3S'@^L_@*)\(G.P>\""<:)Z(ML)&")="00B=Z+G"3H`@``"?Z+?"0<
M@</6P6+*B70D%(MT)$`!V#-T)!")TS'UBW0D&`'HB?V)]XGQ#ZSO&\'M&XE\
M)#C!X06);"0\BVPD.`G-`>@Q[8G'BT0D((G!#Z3#'L'A'@^LT`*)SL'J`@G&
M"=.+1"0HBU0D+(ET)"")7"0D`X0D\`(``(M,)$`3E"3T`@``!=;!8LJ#T@`Q
MVXMT)!`!P8GX$=.)3"0H,W0D((GJB5PD+(M<)$B+3"0H,?,!V<'@!8E$)"B)
M^`^D^@6+="0H#ZSH&XE4)"R)ZHE$)#@+="0XP>H;B?")5"0\BU0D'`'(BTPD
M5(D!BT0D,,=!!``````!^,=!#`````")00B+1"08B<8/K-`"P>8>B?4)Q8M$
M)"")Z8ML)%0##"0#1"0(B4T0QT44`````(E%&(M$)!`#1"18QT4<`````(E%
M(,=%)`````"+A"3\`@``92L%%````'4+@<0,`P``6UY?7</H-@4``(VV````
M`%/H&KC__X'#4F(``(/L%&I\Z,JS___'``$C16?'0`0`````QT`(B:O-[\=`
M#`````#'0!#^W+J8QT`4`````,=`&'94,A#'0!P`````QT`@\.'2P\=`)```
M``#'0"@`````QT`L`````,=`,`````#'0#0`````QT!X`````(/$&%O#C;0F
M`````(VV`````.CK`P``!<-A``!55U93@^P<BTPD.(ML)#")1"0(B<N)R(MU
M,(M]-,'['\'@`P-%*#'2.T4H&U4L<P:#Q@&#UP")12B)R(G:#ZS8'<'J'<=%
M+``````!\(E%,(M%>!'ZC7TXB54TA<`/A3L!``"#?"0X/P^.B`$``(M$)#B+
M="0T@^A`B40D#,'H!HE$)`B-6`'!XP8#7"0TC;0F`````)"+!H/&0(D'BT;$
MB4<$BT;(B4<(BT;,B4<,BT;0B4<0BT;4B4<4BT;8B4<8BT;<B4<<BT;@B4<@
MBT;DB4<DBT;HB4<HBT;LB4<LBT;PB4<PBT;TB4<TBT;XB4<XBT;\B4<\B>CH
MJ-+__SG>=92+1"0(BTPD#,'@!BG!B4PD.(-\)#@$<E2+`XGZB44XBT0D.(M,
M)#B+1`/\B40/_(U'!(/@_"G"*=,#5"0X@^+\@_H$<A*#XOPQ]HL,,XD,,(/&
M!#G6<O.+1"0XB45X@\0<6UY?7<.-M@````"+1"0XA<!TXP^V`XA%./9$)#@"
M=-:+1"0XBTPD.`^W1`/^9HE$#_[KPHVT)@````"Z0````"G".U0D.`]/5"0X
M@^P$`?A2B50D%/]T)#Q0BUPD&.B`LO__BU0D'(M%>(/$$`'0B45X@_A`=8:)
MZ"E4)#@!5"0TZ+W1___I=?[__XVT)@````"0BUPD-.D4____C;0F`````%7H
MW@$``('%LE\``%=64X/L'(M<)#2+="0PBT,HBU,LC7LX#\B)1"0,BT,P#\B)
M1"0(BT,H#ZS0`XG"@^(_C4(!QD03.("-%`>#^#@/CB8!``"Y0````"G!=`TQ
MP,8$`@"#P`$YR'+UB=CH,='__XU7!,=#.``````QP(/B_,='-``````IUXU/
M.(G7P>D"\ZN+1"0(B4-PBT0D#(E#=(G8Z/K0__^+4P2+`X/L#`^LT!B(!HM3
M!(L##ZS0$(A&`8L#B&8"BP.(1@.+4PR+0P@/K-`8B$8$BU,,BT,(#ZS0$(A&
M!8M#"(AF!HM#"(A&!XM3%(M#$`^LT!B(1@B+4Q2+0Q`/K-`0B$8)BT,0B&8*
MBT,0B$8+BU,<BT,8#ZS0&(A&#(M3'(M#&`^LT!"(1@V+0QB(9@Z+0QB(1@^+
M4R2+0R`/K-`8B$80BT,@BU,D#ZS0$(A&$8M#((AF$HM#((A&$U.)Z^B6KO__
M@\0L6UY?7<.-M@````"Y.````#'_*<&#^01R.HU"!,<"`````(/@_,=$"OP`
M````*<(!T8/A_(/Y!`^"Y_[__X/A_#'2B3P0@\($.<IR]NG3_O__9I"%R0^$
MR?[__\8"`/;!`@^$O?[__S'`9HE$"O[IL?[__XL$),.++"3#9I!FD&:09I!5
MZ.[___^!Q<)=``!75E.#[`R)ZXM\)"CH%ZW__XV=[/[__XV%Z/[__RG#P?L"
M="4Q]HVV`````(/L!%?_="0L_W0D+/^4M>C^__^#Q@&#Q!`Y\W7C@\0,6UY?
M7<.-=@##9I!FD&:09I!FD&:09I"04^@:L___@<-270``@^P(_[/L#@``_W0D
M'/]T)!S_="0<Z-JN__^#Q!A;PV:09I"04^CJLO__@<,B70``@^P(Z#RO__]3
M@^P(Z-.R__^!PPM=``"#Q`A;PP,````!``(`)7,O)7,`+W!R;V,O<V5L9B]E
M>&4`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2
M.CI"3T]4`"X`4$%27U1%35``4$%27U!23T=.04U%`#H`+P!015),-4Q)0@!0
M15),3$E"`%!%4DPU3U!4`%!%4DQ)3P!005)?24Y)5$E!3$E:140`4$%27U-0
M05=.140`4$%27T-,14%.`%!!4E]$14)51P!005)?0T%#2$4`4$%27T=,3T)!
M3%]$14)51P!005)?1TQ/0D%,7U1-4$1)4@!005)?5$U01$E2`%!!4E]'3$]"
M04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`%!!4E]#3$5!3CT`,0!,1%],24)2
M05)97U!!5$@`55-%4@!365-414T`+W1M<`!414U01$E2`%1-4`!54T523D%-
M10`E,#)X`'!A<BT`)7,E<R5S)7,`<&%R;``N<&%R`"5S)7-C86-H92TE<R5S
M`"5S)7-T96UP+25U)7,`)7,E<W1E;7`M)74M)74E<P`8`'!E<FP`,`!005(Z
M.E!A8VME<CHZ5D524TE/3@`Q+C`U-``M90`M+0`E<SH@8W)E871I;VX@;V8@
M<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```E
M<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@
M<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*``!5;F%B;&4@
M=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0`````E<SH@8W)E871I;VX@;V8@
M<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE
M:2D*`````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D
M0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C
M:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1P87)?=&5M<"P@)'!R
M;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%
M3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@
M1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I
M<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H
M<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN
M9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL
M("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M
M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ
M5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A
M<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I5
M3DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64[
M"G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@
M73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M
M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*
M9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P
M,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL
M(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG
M<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI
M.PI]"GT@?0I"14=)3B!["B1005)?34%'24,@/2`B7&Y005(N<&U<;B(["DEN
M=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI0
M05(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]
M("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@/2`H"G!A=&A?<V5P("`@(#T^
M("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]
M/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@
M)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<
M7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["F]U=',H<7%;7"1P<F]G
M;F%M92`]("(D<')O9VYA;64B72D["E]S971?<&%R7W1E;7`H*3L*;W5T<RAQ
M<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB72D["FUY("@D
M<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI-04=)0SH@>PIL;V-A;"`D4TE'>U]?
M5T%23E]??2`]('-U8B![?3L*=6YL97-S("AO<&5N(%]&2"P@)SPZ<F%W)RP@
M)'!R;V=N86UE*2!["F]U=',H<7%;0V%N)W0@<F5A9"!F<F]M(&9I;&4@(B1P
M<F]G;F%M92)=*3L@(",@9&]N)W0@=7-E("0A(&AE<F4@87,@:70@<F5Q=6ER
M97,@17)R;F\N<&T*;&%S="!-04=)0SL*?0IM>2`D8VAU;FM?<VEZ92`](#8T
M("H@,3`R-#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R!?1D@["FUY("1M86=I
M8U]P;W,@/2`D<VEZ92`M("1S:7IE("4@)&-H=6YK7W-I>F4[(",@3D]413H@
M)&UA9VEC7W!O<R!I<R!A(&UU;'1I<&QE(&]F("1C:'5N:U]S:7IE"G=H:6QE
M("@D;6%G:6-?<&]S(#X](#`I('L*<V5E:R!?1D@L("1M86=I8U]P;W,L(#`[
M"G)E860@7T9(+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D4$%27TU!
M1TE#*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%27TU!1TE#*2D@
M/CT@,"D@>PHD;6%G:6-?<&]S("L]("1I.PIL87-T.PI]"B1M86=I8U]P;W,@
M+3T@)&-H=6YK7W-I>F4["GT*:68@*"1M86=I8U]P;W,@/"`P*2!["F]U=',H
M<7%;0V%N)W0@9FEN9"!M86=I8R!S=')I;F<@(B1005)?34%'24,B(&EN(&9I
M;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0SL*?0IS965K(%]&2"P@)&UA
M9VEC7W!O<R`M(#0L(#`["G)E860@7T9(+"`D8G5F+"`T.PIS965K(%]&2"P@
M)&UA9VEC7W!O<R`M(#0@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,#L*)&1A=&%?
M<&]S(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D
M8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@
M9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&
M2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I
M.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%
M("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S
M?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA
M;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*
M<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB
M+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z
M<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D
M8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE
M>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M
M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@
M*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8F%S96YA;64D97AT(BP@
M)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PI]"F5L
M<V4@>PHD36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L
M"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*)')E<75I<F5?
M;&ES='LD9G5L;&YA;65]*RL["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C
M86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E
M='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2`D
M36]D=6QE0V%C:&5[)&UO9'5L97T["G)E='5R;B!U;FQE<W,@)&EN9F\["F1E
M;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5].PHD24Y#>R1M;V1U;&5](#T@
M(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@
M86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&
M:6QE+3YN97=?=&UP9FEL92!O<B!D:64@(D-A;B=T(&-R96%T92!T96UP(&9I
M;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H)&EN9F\M/GMB
M=69]*3L*)&9H+3YS965K*#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM
M>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN
M9F\M/GMB=69]*3L*)&EN9F\M/GMF:6QE?2`]("1F:6QE;F%M93L*;W!E;B!M
M>2`D9F@L("<\.G)A=R<L("1F:6QE;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A
M9"`B)&9I;&5N86UE(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T
M<F%P<&EN9R!F86EL960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U;&4A(CL*
M?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V
M>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A
M=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)
M3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E
M<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@
M)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN
M<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I
M;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L
M)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"G5N
M;&5S<R`H)&)U9B!E<2`B4$M<,#`S7#`P-"(I('L*;W5T<RAQ<5M.;R!Z:7`@
M9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M92)=
M*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T
M.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G
M<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID
M96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@
M;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE<W,@
M)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=
M(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD
M(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N
M:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF
M("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!
M4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS
M92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW
M:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4
M=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?
M=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D
M,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@
M)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@
M*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E
M<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I
M('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO
M9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L;V<@9FEL92`B
M)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]
M("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[
M)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR
M97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE
M<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8[
M"F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@
M*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z
M.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H
M0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@
M)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F:6YD('!A<B!F
M:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP
M(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N
M9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@
M9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P87(B73L*?0IM
M>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC
M;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M
M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI
M.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@
M)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F
M:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*
M9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@
M97$@(E!+7#`P,UPP,#0B.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T
M*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/
M7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/
M7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F:6QE
M("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L(#`[
M"FUY("1L;V%D97(["FEF("AD969I;F5D("1D871A7W!O<RD@>PIR96%D(%]&
M2"P@)&QO861E<BP@)&1A=&%?<&]S.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N
M9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)
M37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M
M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T
M(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD
M=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC
M(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@
M(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA
M9VEC*"`K*7U["B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@
M+2!L96YG=&@H)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*
M:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y
M.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D
M=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH
M)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[
M87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB
M97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H($!I;F,[
M"FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?
M<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#
M;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@("`C(%A86"!L:6)?97AT
M('9S(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A8V@@;7D@)&ME>2`H<V]R
M="!K97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*:68@*&1E9FEN
M960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y?2DI('L*
M*"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*9F]R96%C
M:"!M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N
M*BDD?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL87-T.PI]
M"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\*2!["FEF("AM
M>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]
M("@D<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I
M;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*?0IN
M97AT('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT(&EF("1W<FET=&5N>R1N
M86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<
M421L:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M086-K:6YG($9)3$4@
M(B5S(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92DI
M.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D
M9FEL92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O(#T@=6YD968["F]P96X@
M;7D@)&9H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B
M)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@/"1F:#X["F-L;W-E("1F:#L*4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D
M960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@
M/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT
M96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0HD
M9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y
M*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-2
M0S,R*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H*"1C;VYT
M96YT*2DL"B1C;VYT96YT*3L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=
M*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*
M)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PII9B`H
M(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI
M('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["F]P96X@;7D@)&9H
M+"`B/#IR87<B+"`D;W5T.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E("1F
M:#L*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA
M;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1C86-H
M95]N86UE("X](")#04-(12(["B1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PHD
M9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E
M<BDI*3L*)&9H+3YP<FEN="@D4$%27TU!1TE#*3L*)&9H+3YC;&]S93L*8VAM
M;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@
M)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2
M.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ
M1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I
M;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@("`@(",@07)C:&EV
M93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH
M9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A:6QE9#H@
M)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D
M>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE
M2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+
M*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!R
M;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#8T("H@,3`R
M-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE
M>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"54=]
M.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S
M970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^
M;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@
M)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S
M("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O
M;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]
M+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D
M9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0
M?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@
M/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7%;4VMI
M<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@
M870@(B1D97-T7VYA;64B72D["GT@96QS92!["F]U=',H<7%;17AT<F%C=&EN
M9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92)=*3L*)&UE;6)E<BT^
M97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PIC:&UO9"@P-34U+"`D
M9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H
M)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S
M<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@
M+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"
M?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%
M?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A
M=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N
M86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E
M;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL
M93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@
M)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER
M95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*
M<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N
M:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R
M<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE
M879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E
M($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO
M861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q
M=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER
M92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["G)E<75I<F4@
M4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR
M97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I
M;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@
M>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L
M('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C
M:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S
M:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q
M=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T[
M"GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]4
M14U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M
M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.
M5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0
M("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E
M9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S
M97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H
M)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G
M:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*
M96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*
M?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM5
M4T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@/7X@<R]<5R]?+V<["FUY
M("1S=&UP9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(
M*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PII9B`H(21%
M3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE
M*2E;.5TI('L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M92!O<B!D
M:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PIS965K("1F:"P@
M+3$X+"`R.PIM>2`D8G5F.PIR96%D("1F:"P@)&)U9BP@-CL*:68@*"1B=68@
M97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L(#(["G)E860@)&9H+"`D
M8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I<B`N/2`B)'-Y<WM?
M9&5L:6U]8V%C:&4M)&)U9B(["GT*96QS92!["FUY("1D:6=E<W0@/2!E=F%L
M"GL*<F5Q=6ER92!$:6=E<W0Z.E-(03L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!
M+3YN97<H,2D["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@
M9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*)&-T>"T^861D
M9FEL92@D9F@I.PIC;&]S92@D9F@I.PHD8W1X+3YH97AD:6=E<W0["GT@?'P@
M)&UT:6UE.PHD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U]8V%C:&4M)&1I9V5S
M="(["GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y](#T@
M,3L*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[
M4$%27U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL
M87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D
M14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]S879E7V%S('L*;7D@
M*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@
M/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*
M;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["F]P96X@;7D@)&9H+"`G
M/CIR87<G+"`D=&5M<&YA;64@;W(@9&EE('%Q6T-A;B=T('=R:71E("(D=&5M
M<&YA;64B.B`D(5T["G!R:6YT("1F:"`D8V]N=&5N=',["F-L;W-E("1F:#L*
M8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA
M;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I
M.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII
M9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!2
M3T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N
M86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O
M9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U
M8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM
M?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D
M<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D
M9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@
M*"US("(D<')O9VYA;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y
M<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O
M7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X
M:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0
M?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE
M(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL(&QA
M<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE
M?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B
M*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B.PI]
M"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.
M5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES>U]D
M96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G
M;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#
M=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I
M;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M
M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D
M96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B
M(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK
M(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:
M141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@
M0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[)U!!4E\G+B1??3L*
M?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[
M)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S
M("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*;7D@)'!A<E]C;&5A;B`](")?
M7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["FEF("@D14Y6>U!!
M4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"F5L<VEF("@A
M97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*;7D@)'9A;'5E(#T@
M<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*)$5.
M5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<
M4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L
M;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B
M0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S
M:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]
M+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L
M:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E
M(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD
M7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP;#H@
M0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F
M:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D
M<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?
M7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`
M(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?
M5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%
M4E)/4CL*,3L*7U]%3D1?7PH```!P97)L>'-I+F,````!&P,["`$``"````!P
M;?__4`$``!!Q__]@#```8'/__R0!``!P=/__=`$``$!U___L`0``T';__ZP"
M``!@=___^`(``$!X__^4`P``@'K__Q0$````>___<`0``$![__^@!```4'O_
M_[0$``!@??__F`4``)!]__^L!0``D'[__R`&``#P@O__8`8``'"#__^$!@``
MH(/__[`&``"@A/__-`<``$",___H"@``L([__P`,``"ZC___J`P``,"/__^\
M#```@+O__P`-```0O/__)`T``""^__]T#0```,#__\0-```$P/__V`T``!#`
M___L#0``<,#__S@.``"`P/__3`X``+#`__]X#@``%``````````!>E(``7P(
M`1L,!`2(`0<($````!P````T<O__-P`````````4``````````%Z4@`!?`@!
M&PP$!(@!```@````'````!AL__^@`P````X(1@X,2@\+=`1X`#\:.RHR)")T
M````0````/1R___,`````$$."(4"00X,AP-!#A"&!$$.%(,%3@XP`D$.-$$.
M.$0./$$.0$@.,%@*#A1#PPX00<8.#$''#@A!Q0X$00MV"@X40\,.$$'&#@Q!
MQPX(0<4.!$0+0PX40\,.$$/&#@Q!QPX(0<4.!`"\````N````$QS__^.`0``
M`$$."(4"00X,AP-!#A"&!$,.%(,%40[``7(*#A1!PPX00<8.#$''#@A!Q0X$
M0PM##LP!00[0`4@.P`%;#LP!00[0`4@.P`%Q#LP!00[0`68.S`%!#L@!10[,
M`4$.T`%$#M0!0@[8`4(.W`%!#N`!2`[(`40.S`%!#M`!2`[``5@.S`%!#M`!
M2`[``4,.S`%!#M`!2`[``4,.S`%!#M`!2`[``4T.S`%!#M`!4`[``0!(````
M>`$``!QT__^0`````$$."(8"0PX,@P-1#J@!5`ZL`4$.L`%(#J`!80ZH`4(.
MK`%!#K`!2`Z@`6H*#@Q!PPX(0<8.!$$+````F````,0!``!@=/__V0````!!
M#@B%`D$.#(<#00X0A@1##A2#!5$.Q`A8#L@(2P[,"$$.T`A(#L`(50[$"$$.
MR`A"#LP(00[0"$@.P`A-#LP(0@[0"$8.U`A!#M@(00[<"$$.X`A(#L`(50[,
M"$(.T`A(#L0(1`[("$$.S`A!#M`(2`[`"%8*#A1!PPX00<8.#$''#@A!Q0X$
M10L`?````&`"``"D=/__.`(```!!#@B%`D,.#(<#00X0A@1##A2#!4X.3%<.
M4$@.0%H.3$,.4$@.0`)2#DQ+#E!(#D`"9`H.%$'##A!!Q@X,0<<."$'%#@1)
M"P)D#DQ!#E!2#D!4#D1%#DA%#DQ!#E!4#D!9#DA!#DQ!#E!.#D````!8````
MX`(``&1V__]Q`````$$."(8"00X,@P-.#AQ(#B!&#AQ"#B!,#B1,#BA!#BQ!
M#C!(#AQ"#B!&#AQ!#AA"#AQ)#B!!#B1'#BA'#BQ!#C!(#@Q!PPX(0<8.!"P`
M```\`P``B';__SL`````00X(@P).#AQ(#B!,#B1,#BA!#BQ!#C!(#@A!PPX$
M`!````!L`P``F';__P,`````````X````(`#``"4=O__!0(```!!#@B%`D$.
M#(<#00X0A@1!#A2#!5$.T`EO#M@)0@[<"4,.X`E(#M`);0H.%$'##A!!Q@X,
M0<<."$'%#@1&"T,.W`E!#N`)4@[<"4<.V`E%#MP)00[@"4@.T`EU#M@)00[<
M"4$.X`E(#M`)2P[<"4$.X`E(#M`):@[4"4H.V`E$#MP)00[@"4$.Y`E%#N@)
M0@[L"4@.\`E(#M@)10[<"4$.X`E(#M`)5P[8"4$.W`E"#N`)2`[0"0),#M@)
M0@[<"4$.X`E(#M`)5`[<"4$.X`E(#M`)$````&0$``#`=___(P````````!P
M````>`0``-QW___U`````$$."(8"00X,@P-.#A!8#AQ!#B!(#A`"0PX<1PX@
M2`X00PH.#$7##@A!Q@X$1`MC#A1!#AA!#AQ'#B!(#A!%"@X,0\,."$'&#@1#
M"T,.'$<.($@.$$,*#@Q%PPX(0<8.!$$+`#P```#L!```:'C__U@$````00X(
MA0)!#@R'`T$.$(8$3`X4@P5##F`#^P,*#A1!PPX00<8.#$''#@A!Q0X$00L@
M````+`4``(A\__]V`````$$."(,"3@X@90H."$'##@1+"P`H````4`4``.1\
M__\K`````$$."(,"3@X02`X<00X@2`X020X(0<,.!````(````!\!0``Z'S_
M__4`````00X(A0)!#@R'`T$.$(8$00X4@P5.#D`"0@H.%$/##A!!Q@X,0<<.
M"$'%#@1&"T,.2$$.3$$.4$@.0%0*#A1!PPX00<8.#$''#@A!Q0X$2PM##DQ!
M#E!D#D1)#DA!#DQ'#E!!#E1"#EA"#EQ!#F!,#D```+`#````!@``9'W__Y8'
M````00X(A0)!#@R'`T$.$(8$00X4@P51#L""`@*T#LR"`D$.T(("2`[`@@)5
M#LR"`D$.T(("7`[`@@)?#LR"`D<.T(("00[4@@)"#MB"`D(.W(("00[@@@)/
M#L""`@)!#LR"`D$.T(("2`[`@@)U#LR"`D$.T(("2`[`@@).#LR"`D$.T(("
M2@[,@@)$#M""`F8.U(("00[8@@)+#MR"`DL.X(("00[D@@)"#NB"`D(.[(("
M00[P@@)(#LB"`D4.S(("00[0@@)(#L""`EH.R(("10[,@@)$#M""`D@.P(("
M20[,@@)$#M""`D8.U(("1P[8@@)*#MR"`D(.X(("2`[`@@):"@X40\,.$$'&
M#@Q!QPX(0<4.!$H+?0[,@@)!#M""`E<.P(("2P[(@@)!#LR"`D8.T(("3`[`
M@@)+#LR"`D0.T(("2`[`@@)*#LB"`D<.S(("30[0@@)(#L""`@)6#L2"`D$.
MR(("2@[,@@)$#M""`D$.U(("0@[8@@)"#MR"`D$.X(("2`[`@@)E#LR"`D$.
MT(("00[4@@)!#MB"`D0.W(("1`[@@@)$#N2"`D(.Z(("0@[L@@)!#O""`D@.
MP(("0P[(@@)%#LR"`D$.T(("2`[`@@)(#LR"`D0.T(("6P[`@@)Y#LR"`D$.
MT(("2`[`@@)4#LR"`D@.T(("3`[`@@)-"@[(@@)!#LR"`D0.T(("1@[4@@)2
M"T,.S(("00[0@@)8#L""`F@.R(("0@[,@@)$#M""`D@.P(("4@[$@@)"#LB"
M`D(.S(("00[0@@)(#L2"`D(.R(("2`[,@@)!#M""`D@.P(("6@[$@@)"#LB"
M`D(.S(("00[0@@)1#L""`D\.Q(("00[(@@)!#LR"`D$.T(("2`[`@@)##L2"
M`D4.R(("00[,@@)!#M""`D@.P(("2P[,@@)!#M""`D8.S(("00[(@@)$#LR"
M`D@.T(("70[`@@):#LR"`D0.T(("00[4@@)"#MB"`D(.W(("00[@@@)+#L""
M`ET.Q(("1P[(@@)$#LR"`D0.T(("00[4@@)"#MB"`D(.W(("00[@@@)(#L""
M`@)>#LR"`D$.T(("3`[`@@),#LB"`D<.S(("20[0@@)(#L""`@).#L2"`D(.
MR(("0@[,@@)!#M""`D@.Q(("0@[(@@)!#LR"`D$.T(("3`[4@@)'#MB"`D0.
MW(("1`[@@@)!#N2"`D(.Z(("0@[L@@)!#O""`D@.P(("`!0!``"T"0``4('_
M_V8"````00X(A0)!#@R'`T$.$(8$00X4@P5.#DQ4#E!&#DQ"#E!B#D!5#DQ"
M#E!-#E1"#EA!#EQ!#F!(#D!,#DQ(#E!(#D1'#DA%#DQ!#E!+#D!/#DQ"#E!-
M#E1"#EA!#EQ!#F!(#D!I#DQ##E!,#D1!#DA!#DQ!#E!(#D!##DQ"#E!(#D1(
M#DA!#DQ!#E!(#DQ"#E!(#D1'#DA!#DQ!#E!&#DQ"#E!9#D!/#DA%#DQ!#E!(
M#D!G"@X40<,.$$'&#@Q!QPX(0<4.!$0+0PH.3$8.4$@.0$\.3$<.4$D+7`Y,
M20Y04PY`2PY,0@Y01@Y,00Y(00Y,00Y02`Y`1@H.1$<.2$(.3$<.4$4+``!<
M````S`H``*B"__\*`0```$$."(<"00X,A@-!#A"#!$X./%$.0$@.,`)-"@X0
M0<,.#$'&#@A!QPX$1@M(#C1(#CA!#CQ!#D!(#C!4"@X00\,.#$'&#@A!QPX$
M30L```!$````+`L``*AD__](`@```$0,`0!)$`4"=0!!$`<"=7Q$$`8"=7@0
M`P)U=$P/`W5P!@-[`0K!#`$`0<-!QD''0<5##`0$00L0````=`L```J#__\$
M`````````$````"("P``_(+__[HK````00X(A0)!#@R'`T$.$(8$00X4@P5(
M#J`&`Z0K"@X40<,.$$'&#@Q!QPX(0<4.!$$+````(````,P+``!XKO__@P``
M``!!#@B#`DX.'$(.(`)P#@A!PPX$3````/`+``#DKO__"0(```!+#@B%`D$.
M#(<#00X0A@1!#A2#!4,.,`-<`0H.%$'##A!!Q@X,0<<."$'%#@1'"P)##C1#
M#CA(#CQ!#D!3#C!,````0`P``*2P___@`0```$$."(4"3`X,AP-!#A"&!$$.
M%(,%0PXP`IP./`*U#D!*#A1!PPX00<8.#$''#@A!Q0X$1PXP@P6%`H8$AP,`
M`!````"0#```-++__P0`````````$````*0,```DLO__!`````````!(````
MN`P``!RR__]=`````$$."(4"3`X,AP-!#A"&!$$.%(,%0PX@:0XD00XH1`XL
M1`XP30X@1PX40<,.$$'&#@Q!QPX(0<4.!```$`````0-```PLO__`0``````
M```H````&`T``"RR__\K`````$$."(,"3@X01@X41`X81`X<1`X@2`X(0<,.
M!!@```!$#0``,++__Q0`````00X(@P).#A``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````H!<``'`7```!````MP(```$```#'`@```0```-D"```,
M````A!````T````$9```&0````#````;````!````!H````$P```'`````0`
M``#U_O]OI`$```4```!T"```!@```(0"```*````800```L````0````%0``
M```````#````&,$```(```#(`0``%````!$````7````O`X``!$````D#@``
M$@```)@````3````"````!8`````````'@````P```#[__]O`0``"/[__V^4
M#0``____;P(```#P__]OU@P``/K__V\+````````````````````````````
M``````````````````````````````C``````````````,80``#6$```YA``
M`/80```&$0``%A$``"81```V$0``1A$``%81``!F$0``=A$``(81``"6$0``
MIA$``+81``#&$0``UA$``.81``#V$0``!A(``!82```F$@``-A(``$82``!6
M$@``9A(``'82``"&$@``EA(``*82``"V$@``QA(``-82``#F$@``]A(```83
M```6$P``)A,``#83``!&$P``5A,``&83``!V$P``AA,``)83``"F$P``MA,`
M`,83``#6$P``YA,``/83```&%```%A0``"84```V%```1A0`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````_____]QF``!'0T,Z("A$96)I86X@,3$N
M,BXP+3$V*2`Q,2XR+C```"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+F=N=2YB
M=6EL9"UI9``N;F]T92Y!0DDM=&%G`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS
M='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96PN9'EN`"YR96PN
M<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N
M96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1Y;F%M:6,`+F=O
M=``N9&%T80`N8G-S`"YC;VUM96YT````````````````````````````````
M````````````````````````"P````$````"````5`$``%0!```+````````
M```````!`````````!,````'`````@```&`!``!@`0``)```````````````
M!``````````F````!P````(```"$`0``A`$``"````````````````0`````
M````-````/;__V\"````I`$``*0!``#@````!0`````````$````!````#X`
M```+`````@```(0"``"$`@``\`4```8````!````!````!````!&`````P``
M``(```!T"```=`@``&$$``````````````$`````````3@```/___V\"````
MU@P``-8,``"^````!0`````````"`````@```%L```#^__]O`@```)0-``"4
M#0``D`````8````"````!`````````!J````"0````(````D#@``)`X``)@`
M```%``````````0````(````<P````D```!"````O`X``+P.``#(`0``!0``
M`!4````$````"````'P````!````!@```(00``"$$```(```````````````
M!`````````!W`````0````8```"P$```L!```*`#`````````````!`````$
M````@@````$````&````4!0``%`4``"T3P`````````````0`````````(@`
M```!````!@````1D```$9```%```````````````!`````````".`````0``
M``(````89```&&0``"8_``````````````0`````````E@````$````"````
M0*,``$"C```,`0`````````````$`````````*0````!`````@```$RD``!,
MI```C`T`````````````!`````````"N````#@````,`````P````,````0`
M``````````````0````$````N@````\````#````!,````3````$````````
M```````$````!````,8````&`````P````C````(P```$`$```8`````````
M!`````@```#/`````0````,````8P0``&,$``!`!``````````````0````$
M````U`````$````#`````-````#0```0```````````````$`````````-H`
M```(`````P```"#0```0T```,`0`````````````(`````````#?`````0``
M`#``````````$-```!\```````````````$````!`````0````,`````````
<`````"_0``#H```````````````!````````````
